@@ -1,11 +1,11 @@
 package Authen::Htpasswd;
 use strict;
 use base 'Class::Accessor::Fast';
-use Carp qw/ croak /;
+use Carp;
 use IO::LockedFile;
 use Authen::Htpasswd::User;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 my $SUFFIX = '.new';
 
 __PACKAGE__->mk_accessors(qw/ file encrypt_hash check_hashes /);
@@ -79,7 +79,7 @@ sub new {
     }
     
     $self->{encrypt_hash} ||= 'crypt';        
-    $self->{check_hashes} ||= [qw/ md5 sha1 crypt plain /];        
+    $self->{check_hashes} ||= [ Authen::Htpasswd::Util::_supported_hashes() ];        
 
     bless $self, $class;
     $self;
@@ -240,14 +240,20 @@ sub _abort_rewrite {
 
 =head1 AUTHOR
 
-David Kamholz
+David Kamholz C<dkamholz@cpan.org>
 
-davekam at pobox dot com
+Yuval Kogman
 
 =head1 SEE ALSO
 
 L<Apache::Htpasswd>.
 
+=head1 COPYRIGHT & LICNESE
+
+	Copyright (c) 2005 the aforementioned authors. All rights
+	reserved. This program is free software; you can redistribute
+	it and/or modify it under the same terms as Perl itself.
+
 =cut
 
-1;
\ No newline at end of file
+1;
